summaryrefslogtreecommitdiff
path: root/src/lib/decoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2012-11-04 15:58:22 +0000
committerCarl Hetherington <cth@carlh.net>2012-11-04 15:58:22 +0000
commit4fb0a5ab9eebc0f07981edc3a6813102520b8233 (patch)
tree4651bda7e99e3214ce5af2a21e33141d7f308e4a /src/lib/decoder.h
parentc4362a7aa94d9340e38021a67a85635fc6cd4f7d (diff)
Various work on range setting.
Diffstat (limited to 'src/lib/decoder.h')
-rw-r--r--src/lib/decoder.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/decoder.h b/src/lib/decoder.h
index e8e73cc9f..0741c4f54 100644
--- a/src/lib/decoder.h
+++ b/src/lib/decoder.h
@@ -81,7 +81,7 @@ public:
void go ();
/** @return the index of the last video frame to be processed */
- int video_frame_index () const {
+ SourceFrame video_frame_index () const {
return _video_frame_index;
}
@@ -94,11 +94,11 @@ public:
}
/** Emitted when a video frame is ready.
* First parameter is the frame.
* Second parameter is its index within the content.
* Third parameter is either 0 or a subtitle that should be on this frame.
*/
- boost::signals2::signal<void (boost::shared_ptr<Image>, int, boost::shared_ptr<Subtitle>)> Video;
+ boost::signals2::signal<void (boost::shared_ptr<Image>, SourceFrame, boost::shared_ptr<Subtitle>)> Video;
/** Emitted when some audio data is ready */
boost::signals2::signal<void (boost::shared_ptr<AudioBuffers>)> Audio;
@@ -133,7 +133,7 @@ private:
void emit_audio (uint8_t* data, int size);
/** last video frame to be processed */
- int _video_frame_index;
+ SourceFrame _video_frame_index;
std::list<boost::shared_ptr<FilterGraph> > _filter_graphs;
@@ -94,11 +94,11 @@ public:
}
/** Emitted when a video frame is ready.
- * First parameter is the frame.
+ * First parameter is the frame within the source.
* Second parameter is its index within the content.
* Third parameter is either 0 or a subtitle that should be on this frame.